export declare let instrumentation: {
    /**
     * Called when a set of record conflicts has been fully resolved. The
     * parameter indicates the number of server requests that were needed
     * to fully resolve all the record conflicts.
     */
    recordConflictsResolved: (_serverRequestCount: number) => void;
    /**
     * Called during merging of incoming and existing FieldValues.
     * Called when the incoming FieldValue display value is null.
     *
     * Note: Temporary instrumentation to capture distribution and frequency, W-8990630
     * Flipped to counter metric due to W-9611107
     */
    nullDisplayValueConflict: (_fieldInfo: {
        entityName: string;
        fieldName: string;
        fieldType: 'scalar' | 'spanning-record';
        areValuesEqual: boolean | undefined;
    }) => void;
    /**
     * SFDC Throttling
     * getRecordNotifyChange and notifyRecordUpdateAvailable are both throttled
     */
    getRecordNotifyChangeAllowed: () => void;
    getRecordNotifyChangeDropped: () => void;
    notifyRecordUpdateAvailableAllowed: () => void;
    notifyRecordUpdateAvailableDropped: () => void;
    /**
     * RecordRepresentation merge
     * Called when records change apiName
     */
    recordApiNameChanged: (_existingApiName: string, _incomingApiName: string) => void;
    recordTypeIdIsNull: (_apiName: string) => void;
    /**
     * RecordRepresentation merge
     * Called when either incoming or existing RecordRepresentation has a weakEtag=0
     */
    weakEtagZero: (_incomingWeakEtagZero: boolean, _existingWeakEtagZero: boolean, _apiName: string) => void;
    /**
     * getRecord notifyChangeFactory
     * Called when dispatchResourceRequest is resolved/rejected
     */
    getRecordNotifyChangeNetworkResult: (_uniqueWeakEtags: boolean | null, _error?: boolean) => void;
};
/**
 * Allows external modules (typically a runtime environment) to set
 * instrumentation hooks for this module. Note that the hooks are
 * incremental - hooks not suppiled in newInstrumentation will retain
 * their previous values. The default instrumentation hooks are no-ops.
 *
 * @param newInstrumentation instrumentation hooks to be overridden
 */
export declare function instrument(newInstrumentation: Partial<typeof instrumentation>): void;
export type Instrument = typeof instrument;
